@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __author__ = 'Ramiro Gómez <code@ramiro.org>'
 __name__ = 'wcap'
 __description__ = 'Capture web pages as images using Selenium and the FireFox webdriver.'
-__all__ = []
\ No newline at end of file
+__all__ = ['get_browser', 'capture']
+
+
+from .wcap import get_browser, capture
\ No newline at end of file
